@@ -46,6 +46,8 @@ def ddg(
             page_data = resp.json().get("results", None)
         except Exception:
             logger.exception("")
+            if not max_results:
+                return None
         page_results = []
         if page_data:
             for row in page_data:
@@ -98,11 +100,12 @@ def ddg(
             for r in as_completed(fs):
                 if r.result():
                     results.extend(r.result())
-
+        results = results[:max_results]
     else:
-        results = get_ddg_page(page)
+        results = get_ddg_page(page=page)
+        if not results:
+            return None
 
-    results = results[:max_results]
     keywords = keywords.replace(" filetype:", "_")
 
     # save to csv or json file
